@@ -108,6 +108,11 @@ split_line_lha (char *line)
 		fields[i++] = g_strdup ("");
 		fields[i++] = g_strdup ("");
 		line += strlen ("[MS-DOS]");
+
+	} else if (strncmp (line, "[generic]", 9) == 0) {
+		fields[i++] = g_strdup ("");
+		fields[i++] = g_strdup ("");
+		line += strlen ("[generic]");
 	}
 
 	scan = eat_spaces (line);
@@ -133,6 +138,9 @@ get_last_field_lha (char *line)
 	if (strncmp (line, "[MS-DOS]", 8) == 0) 
 		n--;
 
+	if (strncmp (line, "[generic]", 9) == 0) 
+		n--;
+
 	field = eat_spaces (line);
 	for (i = 0; i < n; i++) {
 		field = strchr (field, ' ');
